From 1610b1e9e6ebfd84ff6c7ccad0839cca06ccae42 Mon Sep 17 00:00:00 2001
From: Joey Hess <joey@gnu.kitenet.net>
Date: Tue, 21 Jul 2009 12:38:40 +0200
Subject: [PATCH] update

---
 IkiWiki/Plugin/po.pm | 14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

diff --git a/IkiWiki/Plugin/po.pm b/IkiWiki/Plugin/po.pm
index 6aacca53a..2060ff208 100644
--- a/IkiWiki/Plugin/po.pm
+++ b/IkiWiki/Plugin/po.pm
@@ -152,13 +152,19 @@ sub checkconfig () {
 	push @{$config{wiki_file_prune_regexps}}, qr/\.pot$/;
 
 	# Translated versions of the underlays are added if available.
-	foreach my $underlay ("basewiki", map { m/^\Q$config{underlaydirbase}\E\/*(.*)/ } reverse @{$config{underlaydirs}}) {
+	foreach my $underlay ("basewiki",
+	                      map { m/^\Q$config{underlaydirbase}\E\/*(.*)/ }
+	                          reverse @{$config{underlaydirs}}) {
 		next if $underlay=~/^locale\//;
 
-		# Add underlays containing the po files for slave languages.
+		# Underlay containing pot files.
+		add_underlay("locale/pot/$underlay")
+			if -d "$config{underlaydirbase}/locale/pot/$underlay";
+
+		# Underlays containing the po files for slave languages.
 		foreach my $ll (keys %{$config{po_slave_languages}}) {
-			add_underlay("locale/mo/$underlay")
-				if -d "$config{underlaydirbase}/locale/mo/$underlay";
+			add_underlay("locale/po/$ll/$underlay")
+				if -d "$config{underlaydirbase}/locale/po/$ll/$underlay";
 		}
 	
 		if ($config{po_master_language}{code} ne 'en') {
-- 
2.39.5